// Application : WinformDBF
// DataFactory.prg , Created : 18.03.2019   20:46
// User : Wolfgang

using System.Data
using VO

class DataFactory

static method GetCustomerTable() as DataTable
// creates a .NET DataTable from the DBF data
	local oCustomer		as DataTable
	local oServer		as DBServer
	local nField		as int
	local nFCount		as int
	local aFields		as array
	local cFieldName	as string
	local oRow			as DataRow

	// create the DataTable
	oCustomer			:= DataTable{ "Customer" }
	// open the DBServer readonly and shared
	oServer				:= DBServer{ System.IO.Path.Combine( ProgSettings.DataPath, "Customer.dbf" ), true, true, ProgSettings.DefaultRDD }
	oServer:SetOrder( "Cust1.ntx" )
	oServer:GoTop()
	// build the DataTable field structure, only string fields to keep thing simple
	nFCount				:= oServer:FCount
	aFields				:= ArrayNew( nFCount )
	for nField := 1 upto nFCount
		cFieldName			:= Proper( oServer:FieldName( nField ) )
		aFields[nField]		:= cFieldName
		oCustomer:Columns:Add( cFieldName, System.Type.GetType( "System.String" ) )
	next

	// fill the DataTable with the DBF data
	while ! oServer:EOF
		oRow				:= oCustomer:NewRow()
		for nField := 1 upto nFCount
			cFieldName			:= aFields[nField]
			if IsString( oServer:FieldGet( nField ) )	// convert to string if needed
				oRow[cFieldName]	:= AllTrim( oServer:FieldGet( nField ) )
			else
				oRow[cFieldName]	:= AsString( oServer:FieldGet( nField ) )
			endif
		next
		oCustomer:Rows:Add( oRow )
		oServer:Skip()
	end
	// and close the DBF file
	oServer:Close()

	return oCustomer

static method GetCustomerTableFunction() as DataTable
// creates a .NET DataTable from the DBF data
	local oCustomer		as DataTable
	local nField		as dword
	local nFCount		as dword
	local aFields		as array
	local cFieldName	as string
	local oRow			as DataRow
	local cTableName	as string

	cTableName			:= "Customer"
	// create the DataTable
	oCustomer			:= DataTable{ cTableName }
	// open the DBServer readonly and shared
	if DBUseArea( true, ProgSettings.DefaultRDD, System.IO.Path.Combine( ProgSettings.DataPath, "Customer.dbf" ), cTableName, true, true )
		DBSetOrder( "Cust1.ntx" )
		DBGoTop()
		// build the DataTable field structure, only string fields to keep thing simple
		nFCount				:= FCount()
		aFields				:= ArrayNew( nFCount )
		for nField := 1 upto nFCount
			cFieldName			:= Proper( FieldName( nField ) )
			aFields[nField]		:= cFieldName
			oCustomer:Columns:Add( cFieldName, System.Type.GetType( "System.String" ) )
		next

		// fill the DataTable with the DBF data
		while ! EOF()
			oRow				:= oCustomer:NewRow()
			for nField := 1 upto nFCount
				cFieldName			:= aFields[nField]
				if IsString( FieldGet( nField ) )	// convert to string if needed
					oRow[cFieldName]	:= AllTrim( FieldGet( nField ) )
				else
					oRow[cFieldName]	:= AsString( FieldGet( nField ) )
				endif
			next
			oCustomer:Rows:Add( oRow )
			DBSkip()
		end
		// and close the DBF file
		DBCloseArea()
	endif

	return oCustomer




end class
